Learn R Programming

ribiosUtils (version 1.7.7)

chosenFew: Print the chosen few items of a long vector

Description

Print the chosen few (the first and the last) items of a long vector

Usage

chosenFew(vec, start = 3, end = 1, collapse = ",")

Value

A character string ready to be printed

Arguments

vec

A vector of characters or other types that can be cast into characters

start

Integer, how many elements at the start shall be printed

end

Integer, how many elements at the end shall be printed

collapse

Character used to separate elements

Author

Jitao David Zhang <jitao_david.zhang@roche.com>

Examples

Run this code

lvec1 <- 1:100
chosenFew(lvec1)
chosenFew(lvec1, start=5, end=3)

svec <- 1:8
chosenFew(svec)
chosenFew(svec, start=5, end=4)

Run the code above in your browser using DataLab