Checks whether given character strings point to valid directories
Value
isDir returns logical vector.
assertDir returns an invisible TRUE if directories exist,
otherwise halts and prints error messages.
Details
isDir tests whether the given string represent a valid, existing
directory. assertDir performs a logical test, and stops the program
if the given string does not point to a given directory.
checkDir is synonymous to isDir
See also
file.info, checkFile and
assertFile