Tell whether a character string is a Roche compound ID
Source:R/rocheCompound.R
isRocheCompoundID.RdTell whether a character string is a Roche compound ID
Value
A logical vector of the same length as str, indicating whether each element is a Roche compound ID or not.
Examples
isRocheCompoundID(c("RO1234567", "RO-1234567",
"RO1234567-000", "RO1234567-000-000",
"ROnoise-000-000"))
#> [1] TRUE TRUE TRUE TRUE FALSE